@@ -56,8 +56,9 @@ package inc::MBX::Alien::FLTK::Base;
             close $FH;
             $self->add_to_cleanup($args->{'source'});
         }
-        open(my ($OLDERR), ">&STDERR");
-        close *STDERR if $cbuilder->{'quiet'};
+        #open(my ($OLDERR), ">&STDERR");
+
+        #close *STDERR if $cbuilder->{'quiet'};
         my $obj = eval {
             $cbuilder->compile(
                   ($args->{'source'} !~ m[\.c$] ? ('C++' => 1) : ()),
@@ -72,8 +73,8 @@ package inc::MBX::Alien::FLTK::Base;
                   )
             );
         };
-        open(*STDERR, '>&', $OLDERR)
-            || exit !print "Couldn't restore STDERR: $!\n";
+        #open(*STDERR, '>&', $OLDERR)
+        #    || exit !print "Couldn't restore STDERR: $!\n";
         return $obj ? $obj : ();
     }
 
@@ -273,7 +274,7 @@ int main ( ) {
                 my $print = '';
                 for my $key (@defines) {
                     $print
-                        .= '#ifdef ' 
+                        .= '#ifdef '
                         . $key . "\n"
                         . '    printf("'
                         . $key
@@ -1072,6 +1073,7 @@ END
             $self->notes('timestamp_extracted' => time);
             $self->notes('extract'             => $args{'to'});
             $self->notes('snapshot_path'       => $args{'from'});
+            $self->notes('fltk_patched'        => 0);
             $self->notes(
                      'fltk_dir' => _abs $args{'to'} . sprintf '/%sfltk-%s-%s',
                      $key,
@@ -1159,7 +1161,7 @@ END
     sub ACTION_write_config_yml {
         my ($self) = @_;
         $self->depends_on('configure');
-        require Module::Build::YAML;
+        require YAML::Tiny;
         printf 'Updating %s config... ', $self->module_name;
         my $me        = ($self->notes('config_yml'));
         my $mode_orig = 0644;
@@ -1178,7 +1180,7 @@ END
                               $me, $!
                              }
             );
-        syswrite($YML, Module::Build::YAML::Dump(\%{$self->notes()}))
+        syswrite($YML, YAML::Tiny::Dump(\%{$self->notes()}))
             || $self->_error(
                          {stage   => 'config.yml creation',
                           fatal   => 1,
@@ -1390,7 +1392,8 @@ END
 
     # Patch system
     sub ACTION_patch_fltk {
-        my $s   = shift;
+        my $s = shift;
+        return if $s->notes('fltk_patched');
         my $cwd = _abs(_cwd());
         if (!chdir $s->base_dir()) {
             print 'Failed to cd to base directory';
@@ -1402,14 +1405,18 @@ END
         for my $patch (@patches) {
             printf 'Applying %s... ', _rel($patch);
             printf ucfirst "%sokay\n",
-                _patch_dir($s->notes('extract'), _parse_diff($patch))
-                ? ''
-                : 'not ';
+                $s->_patch_dir($s->fltk_dir, $s->_parse_diff($patch))
+                ? [$s->notes('fltk_patched', gmtime()),'']->[1]
+                : [$s->notes('fltk_patched', 0), 'not ']->[1];
         }
     }
 
     sub _parse_diff {    # Takes unified diff and returns list of changes
-        my ($diff) = @_;
+        my ($s, $diff) = @_;
+        if (!chdir $s->base_dir()) {
+            print 'Failed to cd to base directory';
+            exit 0;
+        }
         $diff = sub {
             open my $FH, '<', shift || return;
             sysread $FH, my $DAT, -s $FH;
@@ -1422,7 +1429,7 @@ END
         #
         my (%patch, $hunk, $from_file, $to_file, $from_time, $to_time);
         while (my $line = shift @diff) {
-            if ($line =~ m[^\@\@\s*-([\d+,]+)\s+\+([\d+,]+)\s*\@\@$])
+            if ($line =~ m[^\@\@\s+-([\d+,?]+)\s+\+([\d+,?]+)\s+\@\@\s*$])
             {    # Unified
                 if ($hunk) {
                     push @{$patch{$to_file}{hunks}}, $hunk;
@@ -1432,10 +1439,10 @@ END
                 ($hunk->{to_pos},   $hunk->{to_len})   = split ',', $2;
                 $hunk->{$_}-- for qw[from_pos to_pos];
             }
-            elsif ($line =~ m[^---\s+([^\s]+)\s+(.+)$]) {
+            elsif ($line =~ m[^---\s+([^\t]+)\t(.+)$]) {
                 ($from_file, $from_time) = ($1, $2);
             }
-            elsif ($line =~ m[^\+\+\+\s+([^\s]+)\s+(.+)$]) {
+            elsif ($line =~ m[^\+\+\+\s+([^\t]+)\t(.+)$]) {
                 ($to_file, $to_time) = ($1, $2);
             }
             else {
@@ -1453,30 +1460,38 @@ END
     }
 
     sub _patch_dir {
-        my ($dir, $patches) = @_;
+        my ($s, $dir, $patches) = @_;
+        if (!chdir $s->base_dir()) {
+            print 'Failed to cd to base directory';
+            exit 0;
+        }
         my $tally;
         require File::Spec;
         for my $file (keys %$patches) {
             my $abs = File::Spec->catfile($dir, $file);
-            my $orig = sub {
-                open my $FH, '<', shift || return;
-                sysread $FH, my $DAT, -s $FH;
-                $DAT;
-                }
-                ->($abs) || die 'Failed to slurp ' . $abs;
+            my $orig;
+            {   open (my $FH, '<',
+                _abs($abs)) || die 'Failed to open ' . _abs($abs) . ' for patching | ' . $!;
+                sysread($FH, $orig, -s $FH) == -s $FH || die 'Failed to slurp ' . _abs($abs) . ' | ' . $!;
+                close $FH;
+            }
             my @orig = split /^/m, $orig;
-            my $data = _patch_data(\@orig, $patches->{$file}{'hunks'});
+            my $data = $s->_patch_data(\@orig, $patches->{$file}{'hunks'});
             $tally += sub {
                 open my $FH, '>', shift || return;
                 syswrite $FH, shift;
                 }
-                ->($abs, $data);
+                ->($abs, join '', @$data) if $data;
         }
         return $tally;
     }
 
     sub _patch_data {
-        my ($text, $hunks) = @_;
+        my ($s, $text, $hunks) = @_;
+        if (!chdir $s->base_dir()) {
+            print 'Failed to cd to base directory';
+            exit 0;
+        }
         for my $hunk (reverse @$hunks) {
             my @pdata;
             my $num = $hunk->{from_pos};
@@ -1487,7 +1502,7 @@ END
                     my ($expect) = ($line           =~ m[^(.+?)(\r\n|\n)$]);
                     next if !$orig || !$expect;
                     return !
-                        sprintf
+                        printf
                         <<'END', $num, $orig, $expect if $orig ne $expect
 Files differ at line %d!
     Expected: %s
@@ -1499,7 +1514,7 @@ END
             }
             splice @$text, $hunk->{from_pos}, $hunk->{from_len}, @pdata;
         }
-        return join '', @$text;
+        return $text;
     }
 
     sub fltk_patches {
